@@ -2,8 +2,6 @@ import logging
 import time
 import traceback
 
-from databand import dbnd_config
-
 
 logger = logging.getLogger(__name__)
 
@@ -40,17 +38,7 @@ def remove_listener_by_name(target, identifier, name):
 
 
 def trace_sqlalchemy_query(connection, cursor, query, parameters, *_):
-    code = "unknown"
-    for (file_path, val1, val2, line_contents) in traceback.extract_stack():
-        if "airflow" not in file_path:
-            continue
-        if (
-            "utils/sqlalchemy.py" in file_path
-            or "utils/db.py" in file_path
-            or "db_utils" in file_path
-        ):
-            continue
-        code = str((file_path, val1, val2, line_contents))
+    code = get_calling_line()
 
     logger.info(
         "\nDBNDSQL QUERY: %s\nPARAMS: %s\nDBNDSQL CODE: %s\nDBNDSQL STACK: %s",
@@ -61,6 +49,21 @@ def trace_sqlalchemy_query(connection, cursor, query, parameters, *_):
     )
 
 
+def get_calling_line():
+    code = "unknown"
+    for (file_path, val1, val2, line_contents) in traceback.extract_stack():
+        if "airflow" not in file_path:
+            continue
+        if (
+            "utils/sqlalchemy.py" in file_path
+            or "utils/db.py" in file_path
+            or "db_utils" in file_path
+        ):
+            continue
+        code = str((file_path, val1, val2))
+    return code
+
+
 def profile_before_cursor_execute(conn, cursor, statement, *_):
     conn.info.setdefault("query_start_time", []).append(time.time())
     logger.debug("Start Query: %s", statement)
@@ -68,7 +71,7 @@ def profile_before_cursor_execute(conn, cursor, statement, *_):
 
 def profile_after_cursor_execute(conn, cursor, statement, parameters, *_):
     total = time.time() - conn.info["query_start_time"].pop(-1)
-    logger.info(
+    logger.debug(
         "Query Complete! %s  \n--> %f seconds\nPARAMS: %s", statement, total, parameters
     )
 
